classdef CBlockablePanel < CPanel
    %CBLOCKABLEPANEL blockable NiHu.Lab panel
    %   CBLOCKABLEPANEL is a CPANEL whos controls can be blocked by calling
    %   its block or unblock members
    %
    % See also: CPanel
    
    properties (Access = private)
        hBlocked    % handles of blockable gui components
        prevState   % previous enable state of blockable gui components
        isBlocked   % boolean indicating whether gui is blocked or not
    end
    
    methods
        function obj = CBlockablePanel(parent, title)
            %CBLOCKABLEPANEL Constructor
            
            obj = obj@CPanel(parent, title);
            obj.isBlocked = false;
        end
        
        function block(obj)
            %BLOCK block the panel
            
            if obj.isBlocked
                return;
            end
            % find components with Enable property
            obj.hBlocked = findobj(obj.hPanel,...
                'Enable', 'on', '-or',...
                'Enable', 'off', '-or',...
                'Enable', 'inactive');
            % store previous state of components
            obj.prevState = get(obj.hBlocked, 'Enable');
            if ~iscell(obj.prevState)   % make sure that we store in cell array
                obj.prevState = {obj.prevState};
            end
            % block components
            set(obj.hBlocked, 'Enable', 'off');
            obj.isBlocked = true;
        end
        
        function unblock(obj)
            %UNBLOCK unblock the panel
            
            if ~obj.isBlocked
                return;
            end
            % reset previous state of components
            for iObj = 1 : length(obj.hBlocked)
                set(obj.hBlocked(iObj), 'Enable', obj.prevState{iObj});
            end
            obj.isBlocked = false;
        end
    end % of public methods
end % of classdef
