classdef CExcitationView < CGuiView & CBlockablePanel
    %CEXCITATIONVIEW View class of CExcitation
    %
    % See also: CExcitation, CTransfer

    properties
        hType       % signal Type handle
        hTable      % table handle where the information is stored
    end
    
    methods
        function obj = CExcitationView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'EXCITATION_PANEL');
            obj = obj@CGuiView(hData, {'Type', 'Amplitude', 'SweepType',...
                'Flim', 'Frequency', 'Phase', 'NoiseType', 'RMS', 'NoiseColor', 'Fc'});
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH Called when the GUI needs to be updated
            
            type = lower(obj.hData.Type);
            
            [~, v] = ismember(type, lower(get(obj.hType, 'String')));
            set(obj.hType, 'Value', v);
            
            switch type
                case 'mls'
                    Data = {obj.hData.Amplitude};
                    CN = {'Amp [V]'};
                    CF = {'numeric'};
                case 'noise'
                    Data = {obj.hData.RMS, obj.hData.NoiseType, obj.hData.NoiseColor, obj.hData.Fc};
                    CN = {'RMS [V]', 'Type', 'Color', 'Fc [Hz]'};
                    CF = {'numeric', {'uniform', 'gaussian'}, {'red', 'pink', 'white', 'blue', 'purple'}, 'numeric'};
                case 'harmonic'
                    Data = {obj.hData.Amplitude, obj.hData.Phase, obj.hData.Frequency};
                    CN = {'Amp [V]', 'Phas [o]', 'Freq [Hz]'};
                    CF = {'numeric', 'numeric', 'numeric'};
                case {'sweep'}
                    Data = {obj.hData.Amplitude, obj.hData.SweepType, obj.hData.Flim(1), obj.hData.Flim(2)};
                    CN = {'Amp [V]', 'Type', 'F1 [Hz]', 'F2 [Hz]'};
                    CF = {'numeric', {'lin', 'exp'}, 'numeric', 'numeric'};
            end
            set(obj.hTable, 'Data', Data, 'ColumnName', CN, 'ColumnFormat', CF);
        end
        
        function TypeCallback(obj)
            %TYPECALLBACK called when exc. type is modified
            
            s = get(obj.hType, 'String');
            obj.hData.Type = s{get(obj.hType, 'value')};
        end
        
        function TableCallback(obj)
            %TABLECALLBACK called when parameters are changed
            
            Data = get(obj.hTable, 'Data');
            switch lower(obj.hData.Type)
                case 'mls'
                    obj.hData.Amplitude = Data{1};
                case {'noise'}
                    obj.hData.RMS = Data{1};
                    obj.hData.NoiseType = Data{2};
                    obj.hData.NoiseColor = Data{3};
                    obj.hData.Fc = Data{4};
                case 'harmonic'
                    obj.hData.Amplitude = Data{1};
                    obj.hData.Phase = Data{2};
                    obj.hData.Frequency = Data{3};
                case {'sweep'}
                    obj.hData.Amplitude = Data{1};
                    obj.hData.SweepType = Data{2};
                    obj.hData.Flim = [Data{3} Data{4}];
            end
        end
    end % of public methods
    
    methods (Access = private)
        function InitObject(obj)
            obj.hType = uicontrol('Parent', obj.hPanel, 'Style', 'popupMenu', ...
                'String', obj.hData.Types, 'Value', 1, ...
                'Callback', @(src, event)TypeCallback(obj), ...
                'Position', [0, 0, CSetupClass.itemWidth, CSetupClass.itemHeight]);
            
            obj.hTable = uitable('Parent', obj.hPanel, 'RowName', [],...
                'Units', 'Pixels', 'ColumnWidth', {50 50 50 50}, ...
                'ColumnEditable', true(1,4), ...
                'CellEditCallback', @(src, event)TableCallback(obj), ...
                'Data', {1 2 3 4}, 'Position', [0, 0, 100, 10]);

            e = extent(obj.hTable);
            set(obj.hTable, 'Position', e);
            
            GuiLayout.ApplyLayout(obj.hPanel, {{obj.hType, [0 0]};
                {obj.hTable, [0 0]}});
        end
    end % of private methods
end % of classdef
