classdef CFileSelectView < CGuiView & CBlockablePanel
    %CFILESELECTVIEW NiHu.Lab panel for file selection

    properties (Access = private)
        hFileName   % handle where the file name is stored
        hDirName    % handle where the file name is stored
        hType       % handle of file type button
        
        matIcon     % matlab icon
        txtIcon     % text icon
        binIcon     % binary icon
    end
    
    methods
        function obj = CFileSelectView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'FILE_SELECT_PANEL');
            obj = obj@CGuiView(hData, {'FileName', 'Directory', 'iType'});
            im = importdata([matlabroot, '/toolbox/matlab/icons/matlabicon.gif']);
            obj.matIcon = ind2rgb(im.cdata, im.colormap);
            im = importdata([matlabroot, '/toolbox/matlab/icons/tool_text.gif']);
            obj.txtIcon = ind2rgb(im.cdata, im.colormap);
            im = importdata(fullfile(fileparts(mfilename('fullpath')), 'data', 'tool_bin.gif'));
            obj.binIcon = ind2rgb(im.cdata, im.colormap);
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH Called when the GUI needs to be updated
            
            set(obj.hFileName, 'String', obj.hData.FileName);
            set(obj.hDirName, 'String', obj.hData.Directory);
            switch obj.hData.Type
                case 'txt'
                    set(obj.hType, 'CData', obj.txtIcon);
                case 'mat'
                    set(obj.hType, 'CData', obj.matIcon);
                case 'bin'
                    set(obj.hType, 'CData', obj.binIcon);
            end
        end
        
        function FileCallback(obj)
            %FILECALLBACK called when the filename is changed
            
            obj.hData.FileName = get(obj.hFileName, 'String');
            obj.hData.NextAvailable();
        end
    end % of public methods
    
    methods (Access = private)
        function InitObject(obj)
            obj.hFileName = uicontrol('Parent', obj.hPanel, ...
                'Style', 'Edit',...
                'units', 'pixels', ...
                'Callback', @(src,event)FileCallback(obj), ...
                'HorizontalAlignment', 'left');
            obj.hDirName = uicontrol('Parent', obj.hPanel, ...
                'Style', 'Edit',...
                'units', 'pixels', ...
                'enable', 'inactive', ...
                'HorizontalAlignment', 'left');
            butNext = uicontrol('Parent', obj.hPanel, 'Style', 'pushButton',...
                'String', '+',...
                'ToolTipStr', CBabel.getInstance().getText('NEXT_AVAILABLE_FILENAME'), ...
                'Callback', @(src,event)NextAvailable(obj.hData), ...
                'Position', [0, 0, CSetupClass.itemHeight, CSetupClass.itemHeight]);
            im = importdata([matlabroot, '/toolbox/matlab/icons/foldericon.gif']);
            butDir = uicontrol('Parent', obj.hPanel, 'Style', 'pushButton',...
                'String', '',...
                'CData', ind2rgb(im.cdata, im.colormap), ...
                'ToolTipStr', CBabel.getInstance().getText('SELECT_DIRECTORY'), ...
                'Callback', @(src,event)DirSelect(obj.hData), ...
                'Position', [0, 0, CSetupClass.itemHeight, CSetupClass.itemHeight]);
            obj.hType = uicontrol('Parent', obj.hPanel, 'Style', 'pushButton',...
                'String', '', ...
                'ToolTipStr', CBabel.getInstance().getText('CHANGE_FILE_TYPE'), ...
                'Callback', @(src,event)SwitchType(obj.hData), ...
                'Position', [0, 0, CSetupClass.itemHeight, CSetupClass.itemHeight]);
            l1 = {{obj.hFileName, [-1 0]}, {butNext, [0 0]}, {butDir, [0 0]}, {obj.hType, [0 0]}};
            l2 = {{obj.hDirName, [-1 0]}};
            GuiLayout.ApplyLayout(obj.hPanel, {{l1, [-1 0]}; {l2, [-1 0]}});
        end
    end % of private methods
end % of classdef
