classdef CUiTabGroup < CContained
    %CUITABGROUP Class to describe a group of UiTabs
    
    properties (Access = private)
        tabs
    end
    
    methods
        function obj = CUiTabGroup(hParent)
            warning off MATLAB:uitabgroup:OldVersion;
            
            veryear = sscanf(version('-release'), '%d');
            if veryear >= 2016
                clbck = 'SelectionChangedFcn';
            else
                clbck = 'SelectionChangeCallback';
            end
            obj.hContainer = uitabgroup('parent', hParent, ...
                clbck, @(src,event)tabSwitchFunction(obj, event));
            obj.tabs = CList;
        end
        
        function register(obj, hTab)
            % Add an object to the list of Tabs
            obj.tabs.pushBack(hTab);
        end
        
        function block(obj)
            % Block all Tabs
            hGroup = obj.getContainer();
            n = length(get(hGroup, 'Children'));
            
            veryear = sscanf(version('-release'), '%d');
            if veryear >= 2016
                i = find(ismember(get(hGroup, 'Children'), get(hGroup, 'SelectedTab')));
                jTabGroup = findjobj(handle(hGroup), 'class', 'TabbedPane');
            else
                i = get(hGroup, 'SelectedIndex');
                jTabGroup = getappdata(handle(hGroup),'JTabbedPane');
            end
            
            for j = setdiff(1 : n, i)
                jTabGroup.setEnabledAt(j-1, false);  % enable specific
            end
        end
        
        function unblock(obj)
            % Unblock all Tabs
            hGroup = obj.getContainer();
            n = length(get(hGroup, 'Children'));
            
            veryear = sscanf(version('-release'), '%d');
            if veryear >= 2016
                jTabGroup = findjobj(handle(hGroup), 'class', 'TabbedPane');
            else
                jTabGroup = getappdata(handle(hGroup),'JTabbedPane');
            end
            
            for j = 1 : n
                jTabGroup.setEnabledAt(j-1, true);  % enable specific
            end
        end
        
        function tabSwitchFunction(obj, event)
            % Function called when user clicks on one of the tabs
            if isEmpty(obj.tabs)
                return
            end
            % Get first data member of List of Tabs
            h = obj.tabs.getHead().getNext();
            while ~isempty(h)
                % find old a new Tab in List
                d = h.getData();
                if d.getContainer() == event.OldValue
                    oldMember = d;
                elseif d.getContainer() == event.NewValue
                    newMember = d;
                end
                h = h.getNext();
            end
            % Hide old Tab
            oldMember.hide();
            % Show new Tab
            newMember.show();
        end
        
        function delete(obj)
            disp('CUiTabGroup deleted');
        end
    end
end

