% MEASURE
%
% Modules
%   CNiHuLab             - Main module of NiHu.Lab
%   CChannelSetup        - Nihu.Lab module for channel setup
%   CMonitor             - Nihu.Lab module for signal monitoring
%   CCalibration         - Nihu.Lab module for sensor calibration
%   CRecord              - Nihu.Lab module for signal recording
%   CStreamViewer        - Nihu.Lab module for stream display
%   CTransfer            - Nihu.Lab module for Transfer Function Measurement
%   CImpact              - Nihu.Lab module for Impact Testing
%   CDistortion          - Nihu.Lab module for Distortion Measurement
%
% Classes
%   CAcqSetup            - NiHu.Lab class for acquisition setup
%   CAmpChannel          - NiHu.Lab class for amplifier channel handling
%   CAmpSetter           - NiHu.Lab panel for adjusting preamp amplification
%   CAmplifier           - NiHu.Lab class for Amplifier handling
%   CAverage             - NiHu.Lab class for averaging parameters
%   CCalPanel            - NiHu.Lab Calibration Channel Selection Panel
%   CCalSelect           - NiHu.Lab class for calibrator handling
%   CCalibrator          - NiHu.Lab class for Calibrator handling
%   CChannel             - NiHu.Lab class for Channel handling
%   CChSetupSensitive    - object sensitive to Channel Setup Change
%   CDevice              - NiHu.Lab class for Device handling
%   CDirection           - NiHu.Lab enumeration for Directions
%   CDistSignal          - NiHu.Lab class for harmonic distortion signal selection
%   CExcitation          - NiHu.Lab class for excitation signal generation
%   CFileSelect          - NiHu.Lab class for file selection
%   CGraphData           - Plot window class
%   CLevelMeter          - NiHu.Lab class for level meter
%   CMultiAmpSetter      - Class to set amplification of multiple amplifiers
%   CReferenceSelect     - Reference selection for transfer function measurement
%   CStreamer            - 
%   CTimeElapsed         - NiHu.Lab class for measuring time elapsed
%   CTrigger             - NiHu.Lab class for trigger settings
%   CInput               - NiHu.Lab class for Channel handling
%   CModule              - An input or output hardware module
%   COperationMode       - NiHu.Lab class for operation mode
%   CQuantity            - NiHu.Lab class for Quantity handling
%   CSensor              - NiHu.Lab class for CSensor handling
%
% View classes
%   CAcqSetupView        - NiHu.Lab gui panel for setting acquisition setup
%   CAverageView         - NiHu.Lab panel for adjusting averaging parameters
%   CCalSelectView       - NiHu.Lab panel for calibrator selection
%   CChannelView         - View class of CChannel
%   CDistSignalView      - NiHu.Lab panel for harmonic distortion signal selection
%   CExcitationView      - View class of CExcitation
%   CFileSelectView      - NiHu.Lab panel for file selection
%   CGraphDataView       - View class of CGraphData
%   CHardwareView        - NiHu.Lab class for displaying Hardware status
%   CLevelMeterView      - CLEVELMETER Class to measure channel signal levels
%   CReferenceSelectView - CREFERENCESELECTVIEW
%   CStreamerView        - NiHu.Lab panel for controlling the CStreamer module
%   CTimeElapsedView     - View class of CTimeElapsed
%   CTriggerView         - View class of CTrigger
%
% Gui Elements
%   CBlockablePanel      - blockable NiHu.Lab panel
%   CGuiModule           - CGuiModule A general base class for a Gui Module in separate Figure.
%   CGuiView             - NiHu.Lab class for a GUI View
%   CPanel               - Class representing a gui panel
%   CSetupClass          - NiHu.Lab class to handle exit requests
%   CContained           - A class that is contained by a parent object
%   CCopyableObject      - An object that can be deep-copied
%   CGuiTab              - Class to represent a GUI tab
%   CList                - 
%   CListElem            - 
%   CUiTab               - A tab in a GUI
%   CUiTabGroup          - 
%   dcopy                - Deep copy of an object
%
% Hardware
%   CCRIO                - NiFpga container class generated by NiFpga
%   CFPGA                - Hardware class to provide interface to NI CRIO FPGA
%   CDAQ                 - Ni DAQ hardware object
%   CSimulator           - Simulated hardware class
%   CPlayrec             - Hardware class to provide interface to SoundCards using Playrec
%   CNi9234Hardware      - Base class of all Ni 2934 modules
%   CHardware            - A measurement hardware abstract base class
%   FindHardware         - Search for connected Hardwares
%
% Signal processing
%   LevelPhase           - Level and phase of a harmonic signal component
%   expfit               - Fit exponential function
%   circorr              - Circular auto and cross correlation
%   colornoise           - Colored noise signal
%   mlssignal            - Maximum Length Sequence
%   sweepsignal          - Sweep Sine Signal
%   transferest          - Estimate transfer of linear system
%
% PostProcessing
%   LoadStream           - 
%   PlotStream           - 
%
% auxilliray
%   Compile              - Compile NIHu.Lab
%   soundsignal          - Generate Sound Signal
%   Clear                - Clear alles geexcire
%   classdiagram         - 
%   extent               - 
%
%   NiHu                 - NiHu is a wrapper class of clas CNiHuLab.
%
%   CBabel               - Gui language translation class
%   SelectModules        - Select Gui Modules for better performance
