function selection = SelectModules
%SELECTMODULES Select Gui Modules for better performance
%   Sel = SELECTMODULES opens a gui and lets the user select the NiHu.Lab
%   modules.

% selectable modules
Modules = {
    'Monitor'
    'Calibration'
    'Record'
    'Stream Viewer'
    'Transfer'
    'Direction Characteristics'
    'Impact Testing'
    'Distortion'
    'Spectral Monitor'
    };

% draw main figure gui
MainFigure = figure(...
    'Name', 'Select Modules',...
    'NumberTitle', 'off', ...
    'Units', 'Pixels',...
    'MenuBar', 'None',...
    'Resize', 'off', ...
    'Color', get(0,'defaultUicontrolBackgroundColor'),...
    'Visible', 'on',...
    'CloseRequestFcn', '');

% populate gui with controls
c = uicontrol(...
    'parent', MainFigure, ...
    'style', 'listbox', ...
    'string', Modules, ...
    'min', 1, ...
    'max', 3, ...
    'units', 'pixels', ...
    'position', [0 0 300 150]);

b = uicontrol(...
    'parent', MainFigure, ...
    'style', 'pushbutton', ...
    'string', 'Select', ...
    'callback', 'uiresume');

% arrange gui elements
GuiLayout.ApplyLayout(MainFigure, {{c, [0 0]}; {b, [-0 0]}});

% block execution until user presses the button
uiwait;

% read selection
selection = get(c, 'string');
selection = selection(get(c, 'value'));

% close the gui window
set(MainFigure, 'CloseRequestFcn', 'closereq');
close(MainFigure);

end
