function c = circorr(y,x)
%CIRCORR Circular auto and cross correlation
%   C = CIRCORR(Y, X) computes the circular crosscorrelation of the
%   signals X and Y.
%   C = CIRCORR(X) computes the circular autocorrelation of the signal X
%
% The circular cross correlation C of signals y and x is defined as
%
% C_n = 1/N * sum_{i=1 to N} y_i x_{i+n-1}, n = 1 .. N

% Copyright 2010-2010 Peter Fiala

if nargin == 1
    x = y;  % autocorrelation
end

n = size(x,1); % number of samples
s = size(y); % number of response signals
s(1) = 1;
X = fft(x,[],1); % Fourier transform of excitation
Y = fft(y,[],1); % Fourier transform of responses
C = Y .* repmat(conj(X), s); % CrossCorr in frequency domain
c = ifft(C, [], 1) / n; % inverse Fourier transform
end