#include "signal.h"
#include <math.h>   /* for sweep sine */

static uint32_t mlsTaps[] = {
    0x00000001, 0x00000003, 0x00000006, 0x0000000c, /* N =  1 to  4 */
    0x00000014, 0x00000030, 0x00000048, 0x000000b8, /* N =  5 to  8 */
    0x00000110, 0x00000240, 0x00000500, 0x00000ca0, /* N = 19 to 12 */
    0x00001b00, 0x00003088, 0x00006000, 0x0000d008, /* N = 13 to 16 */
    0x00012000, 0x00020400, 0x00063000, 0x00090000, /* N = 17 to 20 */
    0x00100002, 0x00200001, 0x00400010, 0x0080000d, /* N = 21 to 24 */
    0x01000004, 0x020000c1, 0x040000c1, 0x08000004, /* N = 25 to 28 */
    0x10000002, 0x2000c001, 0x40000004, 0x8c000001 /*  N = 29 to 32 */
};

void mlssignal(uint8_t N, uint8_t *mls)
{
    uint32_t mask, M, i, reg;

	mask = mlsTaps[N-1];
	M = (1 << N) - 1;
	reg = 0xFFFFFFFF;
    for (i = M; i; --i)
	{
        uint32_t masked = mask & reg;
		uint8_t bit = 0, ic;
        for (ic = N; ic; ic--)
		{
            bit ^= (masked & 0x00000001);
			masked >>= 1;
		}
        mls[i-1] = bit;
        reg = (reg << 1) + bit;
    }
}

#define PI 3.141592653589793
enum sweeptype {LIN = 0, EXP};

void sweepsignal(char type, double flim[], uint32_t nSamp, double fs, double *sweep) {
    double phase, freq, df;
    uint32_t iSamp;
    switch (type) {
        case LIN: /* linear sweep */
            freq = 2*PI*flim[0]/fs;
            df = 2*PI*(flim[1] - flim[0])/(nSamp-1)/fs;
            for (iSamp = 0, phase = 0; iSamp < nSamp; iSamp++, freq+=df) {
                phase += freq;
                sweep[iSamp] = sin(phase);
            }
            break;
        case EXP: /* exponential sweep */
            freq = 2*PI*flim[0]/fs;
            df = exp(log(flim[1]/flim[0])/(nSamp-1));
            for (iSamp = 0, phase = 0; iSamp < nSamp; iSamp++, freq*=df) {
                phase += freq;
                sweep[iSamp] = sin(phase);
            }
            break;
    }
}