#include "DAQmxTask.h"

#include <iostream>
#include <iterator>

void input(DAQmx::Task &task, DAQmx::Device const &device)
{
	task.createInputChannel(device, 0);
	task.setTiming(20000, 1000);
	task.start();

	double buffer[1000];
	int nSampRead = task.read(1000, buffer, 1000);

	std::cout << nSampRead << " samples read." << std::endl;

	task.stop();
}


void output(DAQmx::Task &task, DAQmx::Device const &device)
{
	unsigned const N = 1000;
	task.createOutputChannel(device, 0);
	task.setTiming(20000, N);
	task.configOutputBuffer(N);

	double buffer[N];
	for (int i = 0; i < N; ++i)
		buffer[i] = 0.0;
	int written = task.write(N, buffer);
	std::cout << written <<" samples written\n";

	task.start();

	task.waitUntilDone(2.0);

	task.stop();
}


int main(void)
{
	try
	{
		auto devices = DAQmx::getSystemDevices();
		std::ostream_iterator<DAQmx::Device> outit(std::cout, "\n");
		std::copy(devices.begin(), devices.end(), outit);

		DAQmx::Task task("csucsu");

		//		input(task, devices[0]);
		output(task, devices[0]);
	}
	catch (DAQmx::Exception const &e)
	{
		std::cerr << e.what() << std::endl;
	}

	return 0;
}
