#include "nihu_daqmx.h"

#include <stdlib.h>

float64 drand(void)
{
	return (float64)rand() / RAND_MAX;
}

int excite(TaskHandle taskHandle)
{
	int32 err, i;
	float64 fs = 40000;
	int nChan = 2;
	int nSamplesPerChannel = 100000;
	int32 nSamplesPerChannelWritten;
	float64 mag = .4;

	float64 *writeArray;
	writeArray = (float64 *)malloc(nChan * nSamplesPerChannel * sizeof(float64));
	for (i = 0; i < nChan * nSamplesPerChannel; ++i)
		writeArray[i] = (2. * drand() - 1.) * mag;
	printf("Array written\n");

	err = DAQmxCfgSampClkTiming(taskHandle, NULL, fs, DAQmx_Val_Rising, DAQmx_Val_FiniteSamps, nSamplesPerChannel);
	if (err != 0)
		printErrorMessage(stderr, err);
	printf("Timing configures\n");

	err = DAQmxCfgOutputBuffer(taskHandle, nSamplesPerChannel);
	if (err != 0)
		printErrorMessage(stderr, err);
	printf("Output buffer configured\n");

	err = DAQmxWriteAnalogF64(taskHandle,
		nSamplesPerChannel, (bool32)0, DAQmx_Val_WaitInfinitely, DAQmx_Val_GroupByScanNumber,
		writeArray, &nSamplesPerChannelWritten, NULL);
	if (err != 0)
		printErrorMessage(stderr, err);
	printf("Output samples written\n");

	err = DAQmxStartTask(taskHandle);
	if (err != 0)
		printErrorMessage(stderr, err);

	while (1)
	{
		bool32 complete;
		DAQmxGetTaskComplete(taskHandle, &complete);
		if (complete)
			break;
		Sleep(10);
	}

	free(writeArray);
}

int measure(TaskHandle taskHandle)
{
	int32 err;
	float64 fs = 51200;
	float64 *readArray;
	int32 sampsPerChanRead;
	int32 sampsPerChanRequested = 40000;
	int nChan = 2;
	int i;

	readArray = (float64 *)malloc(nChan*sampsPerChanRequested*sizeof(float64));

	err = DAQmxCfgSampClkTiming(taskHandle, NULL, fs, DAQmx_Val_Rising, DAQmx_Val_ContSamps,
		(uInt64)(2*fs*nChan));

	if ((err = DAQmxStartTask (taskHandle)) != 0) 
		printErrorMessage(stderr, err);
	printf("Task started successfully\n");

	for (i = 0; i < 10; ++i)
	{
		err = DAQmxReadAnalogF64(taskHandle,
			sampsPerChanRequested, DAQmx_Val_WaitInfinitely, DAQmx_Val_GroupByScanNumber,
			readArray, nChan*sampsPerChanRequested, &sampsPerChanRead, NULL);
		printf("%d samples read per channel.\n", sampsPerChanRead);
	}

	if ((err = DAQmxStopTask (taskHandle)) != 0) 
		printErrorMessage(stderr, err);
	printf("Task stopped successfully\n");

	free(readArray);

	return 0;
}

int runTask(TaskHandle taskHandle)
{
	int32 err, i;
	char devNames[2000];
	char *devName, *end;

	ChassisProperties chassisProperties;

	err = DAQmxGetSysDevNames(devNames, sizeof(devNames));
	if (err != 0)
		printErrorMessage(stderr, err);
	printf("Detected devices:\n%s\n", devNames);

	devName = strstr(devNames, "Dev");
	end = strchr(devName, ',');
	if (end != NULL)
		*end = '\0';
	printf("Selected device: %s\n", devName);

	getChassisProperties(devName, &chassisProperties);
	printChassisProperties(stdout, &chassisProperties);

	for (i = 0; i < 2; ++i)
	{
		char chanName[1000];
		strcpy(chanName, devName);
		strcat(chanName, "/ai");
		sprintf(chanName + strlen(chanName), "%d", i);

		err = DAQmxCreateAIVoltageChan(taskHandle, chanName, NULL, DAQmx_Val_Cfg_Default, -5.0, +5.0, DAQmx_Val_Volts, NULL);
		if (err != 0)
			printErrorMessage(stderr, err);
		printf("Channel %s added succesfully\n", chanName);
	}

	measure(taskHandle);

	return 0;
}

int main(void)
{
	TaskHandle taskHandle;
	int32 err;
	char const *taskName = "MyTask";

	if ((err = DAQmxCreateTask (taskName, &taskHandle)) != 0) 
	{
		printErrorMessage(stderr, err);
		return 1;
	}
	printf("Task \"%s\" created successfully\n", taskName);

	runTask(taskHandle);

	if ((err = DAQmxClearTask (taskHandle)) != 0) 
	{
		printErrorMessage(stderr, err);
		return 1;
	}
	printf("Task \"%s\" cleared successfully\n", taskName);

	return 0;
}

