/** \file nihu_daqmx.h
 * \author Peter Fiala
 * \brief Declaration file of NiHu DAQmx module
 */
#ifndef NIHU_DAQMX_H_DEFINED
#define NMIHU_DAQMX_H_DEFINED

#include <windows.h>
#include "NIDAQmx.h"
#include <stdio.h>

/** \brief integral constants */
enum {
	MAX_STR = 1024,	/**< \brief maximal length of a string in the device structures */
	MAX_MODULES = 4 /**< \brief maximal number of modules in a chassis */
};

/** \brief NI DAQmx Device Properties */
typedef struct DeviceProperties {
	char deviceName[MAX_STR];	/**< \brief The device name as seen in MAX */
	uInt32 productNumber;		/**< \brief The product number */
	char productType[MAX_STR];	/**< \brief The product type name */
	int32 productCategory;		/**< \brief The product category id */
	uInt32 serialNumber;		/**< \brief Serial number */
} DeviceProperties;


/** \brief NI DAQmx Chassis Properties */
typedef struct ChassisProperties {
	DeviceProperties chassisProperties;	/**< \brief The device properties of the chassis */
	char moduleDevNames[MAX_STR];		/**< \brief The module names separated by comma */
	int numModules;						/**< \brief The number of modules */
	DeviceProperties moduleDeviceProperties[MAX_MODULES];	/**< \brief The array of module properties */
} ChassisProperties;

/** \brief Print device properties to a text file
 * \param [in] fp the file pointer to print into
 * \param [in] devProp pointer to the device properties
 */
void printDeviceProperties(FILE *fp, DeviceProperties const *devProp);

/** \brief Print chassis properties to a text file
 * \param [in] fp the file pointer to print into
 * \param [in] chassProp pointer to the chassis properties
 */
void printChassisProperties(FILE *fp, ChassisProperties const *chassProp);

/** \brief Get device properties by device name
 * \param [in] devName the device name
 * \param [out] deviceProperties the structure containing the device properties
 * \return 0 on successful operation
 */
int getDeviceProperties(char const *devName, DeviceProperties *deviceProperties);

/** \brief get chassis properties by device name
 * \param [in] devName the device name
 * \param [out] chassisProperties the structure containing the chassis properties
 * \return 0 on successful operation
 */
int getChassisProperties(char const *devName, ChassisProperties *chassisProperties);
    
/** \brief Print an error message into an output file
 * \param [in] fp the file pointer to print into
 * \param [in] err the error identifier
 */
void printErrorMessage(FILE *fp, int32 err);

#endif // NIHU_DAQMX_H_DEFINED

